@@ -148,6 +148,32 @@ size_t ag_max(size_t a, size_t b) {
     return a;
 }
 
+void generate_hash(const char *find, const size_t f_len, uint8_t *h_table, const int case_sensitive) {
+    int i;
+    for (i = f_len - sizeof(uint16_t); i >= 0; i--) {
+        // Add all 2^sizeof(uint16_t) combinations of capital letters to the hash table
+        int caps_set;
+        for (caps_set = 0; caps_set < (1 << sizeof(uint16_t)); caps_set++) {
+            word_t word;
+            memcpy(&word.as_chars, find + i, sizeof(uint16_t));
+            int cap_index;
+            // Capitalize the letters whose corresponding bits in caps_set are 1
+            for (cap_index = 0; caps_set >> cap_index; cap_index++) {
+                if ((caps_set >> cap_index) & 1)
+                    word.as_chars[cap_index] -= 'a' - 'A';
+            }
+            size_t h;
+            // Find next free cell
+            for (h = word.as_word % H_SIZE; h_table[h]; h = (h + 1) % H_SIZE)
+                ;
+            h_table[h] = i + 1;
+            // Don't add capital letters if case sensitive
+            if (case_sensitive)
+                break;
+        }
+    }
+}
+
 /* Boyer-Moore strstr */
 const char *boyer_moore_strnstr(const char *s, const char *find, const size_t s_len, const size_t f_len,
                                 const size_t alpha_skip_lookup[], const size_t *find_skip_lookup) {
@@ -184,6 +210,43 @@ const char *boyer_moore_strncasestr(const char *s, const char *find, const size_
     return NULL;
 }
 
+const char *hash_strnstr(const char *s, const char *find, const size_t s_len, const size_t f_len, uint8_t *h_table, const int case_sensitive) {
+    if (s_len < f_len)
+        return NULL;
+
+    // Step through s
+    const size_t step = f_len - sizeof(uint16_t) + 1;
+    size_t s_i = f_len - sizeof(uint16_t);
+    for (; s_i <= s_len - f_len; s_i += step) {
+        size_t h;
+        for (h = *(const uint16_t *)(s + s_i) % H_SIZE; h_table[h]; h = (h + 1) % H_SIZE) {
+            const char *R = s + s_i - (h_table[h] - 1);
+            size_t i;
+            // Check putative match
+            for (i = 0; i < f_len; i++) {
+                if ((case_sensitive ? R[i] : tolower(R[i])) != find[i])
+                    goto next_hash_cell;
+            }
+            return R; // Found
+        next_hash_cell:;
+        }
+    }
+    // Check tail
+    for (s_i = s_i - step + 1; s_i <= s_len - f_len; s_i++) {
+        size_t i;
+        const char *R = s + s_i;
+        for (i = 0; i < f_len; i++) {
+            char s_c = case_sensitive ? R[i] : tolower(R[i]);
+            if (s_c != find[i])
+                goto next_start;
+        }
+        return R;
+    next_start:;
+    }
+    return NULL;
+}
+
+
 strncmp_fp get_strstr(enum case_behavior casing) {
     strncmp_fp ag_strncmp_fp = &boyer_moore_strnstr;
 
@@ -474,7 +537,7 @@ int is_symlink(const char *path, const struct dirent *d) {
 int is_named_pipe(const char *path, const struct dirent *d) {
 #ifdef HAVE_DIRENT_DTYPE
     if (d->d_type != DT_UNKNOWN) {
-        return d->d_type == DT_FIFO;
+        return d->d_type == DT_FIFO || d->d_type == DT_SOCK;
     }
 #endif
     char *full_path;
@@ -485,7 +548,7 @@ int is_named_pipe(const char *path, const struct dirent *d) {
         return FALSE;
     }
     free(full_path);
-    return S_ISFIFO(s.st_mode);
+    return S_ISFIFO(s.st_mode) || S_ISSOCK(s.st_mode);
 }
 
 void ag_asprintf(char **ret, const char *fmt, ...) {
